import { GulpTask, IBuildConfig } from '@microsoft/gulp-core-build';
import { Gulp } from 'gulp';
import * as Rollup from 'rollup';
import { RollupOptions } from 'rollup';
/**
 * @public
 */
export interface IRollupTaskConfig {
    /**
     * Path to a rollup config. A path to a config takes precedence over the "config" option.
     */
    configPath?: string;
    /**
     * Rollup config object. If a path is specified by "configPath," and it is valid, this option is ignored.
     */
    config?: RollupOptions | RollupOptions[];
    /**
     * An array of regular expressions or regular expression strings.
     */
    suppressWarnings?: (string | RegExp)[];
    /**
     * An instance of the rollup compiler object.
     */
    rollup?: typeof Rollup;
    /**
     * If true, a summary of the compilation will be printed after it completes. Defaults to true.
     */
    printStats?: boolean;
}
/**
 * @public
 */
export declare class RollupTask<TExtendedConfig = {}> extends GulpTask<IRollupTaskConfig & TExtendedConfig> {
    private static forEachAsync;
    constructor(extendedName?: string, extendedConfig?: TExtendedConfig);
    executeTask(gulp: Gulp, completeCallback: (error?: string) => void): Promise<void>;
    isEnabled(buildConfig: IBuildConfig): boolean;
}
//# sourceMappingURL=RollupTask.d.ts.map