"use strict";
// @microsoft/gulp-core-build-webpack
//
// Copyright (c) Microsoft Corporation. All rights reserved.
//
// MIT License
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const gulp_core_build_1 = require("@microsoft/gulp-core-build");
const path_1 = require("path");
/**
 * @public
 */
class RollupTask extends gulp_core_build_1.GulpTask {
    constructor(extendedName = 'rollup', extendedConfig) {
        super(extendedName, Object.assign({ configPath: './rollup.config.js', suppressWarnings: [], printStats: true }, extendedConfig) // tslint:disable-line:no-any
        );
    }
    static forEachAsync(array, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            for (let i = 0; i < array.length; i++) {
                yield callback(array[i], i, array);
            }
        });
    }
    executeTask(gulp, completeCallback) {
        return __awaiter(this, void 0, void 0, function* () {
            const shouldInitRollup = process.argv.indexOf('--initrollup') > -1;
            if (shouldInitRollup) {
                this.log('Initializing a rollup.config.js, which bundles lib/index.js ' +
                    'into dist/packagename.js as a UMD module.');
                this.copyFile(path_1.resolve(__dirname, 'rollup.config.js'));
                return;
            }
            else {
                let rollupOptions;
                if (this.taskConfig.configPath && this.fileExists(this.taskConfig.configPath)) {
                    try {
                        const path = this.resolvePath(this.taskConfig.configPath);
                        const config = require(path);
                        rollupOptions = config instanceof Array ? config : [config];
                    }
                    catch (err) {
                        throw new Error(`Error parsing rollup config '${this.taskConfig.configPath}': ${err}`);
                    }
                }
                else if (this.taskConfig.config) {
                    const config = this.taskConfig.config;
                    rollupOptions = config instanceof Array ? config : [config];
                }
                else {
                    this.logWarning('No rollup config has been provided. Run again using --initrollup to create a default config, ' +
                        'or call rollup.setConfig({ configPath: null }) in your gulpfile.');
                    return;
                }
                const rollup = this.taskConfig.rollup || require('rollup');
                yield RollupTask.forEachAsync(rollupOptions, (options) => __awaiter(this, void 0, void 0, function* () {
                    const { input, output } = options;
                    if (output instanceof Array) {
                        for (const value of output) {
                            this.log(`Bundling '${input}' into '${value.file}' as a '${value.format}' module.`);
                        }
                        const build = yield rollup.rollup(options);
                        for (const value of output) {
                            yield build.write(value);
                        }
                    }
                    else if (output !== undefined) {
                        this.log(`Bundling '${input}' into '${output.file}' as a '${output.format}' module.`);
                        const build = yield rollup.rollup(options);
                        yield build.write(output);
                    }
                    else {
                        this.log(`Bundling '${input}' into 'dist/index.js' as a 'cjs' module.`);
                        const build = yield rollup.rollup(options);
                        yield build.write({ file: 'dist/index.js', format: 'cjs' });
                    }
                }));
            }
        });
    }
    isEnabled(buildConfig) {
        return super.isEnabled(buildConfig) && !!this.taskConfig.configPath;
    }
}
exports.RollupTask = RollupTask;
//# sourceMappingURL=RollupTask.js.map